@@ -1,15 +1,16 @@
 from PyQt5.QtGui import QColor
+from PyQt5.QtWidgets import qApp
 from pyqt_titlebar_buttons_widget import TitlebarButtonsWidget
 
 
 class MacButtonsWidget(TitlebarButtonsWidget):
     def __init__(self, base_widget=None, hint=['min', 'max', 'close']):
         super().__init__(base_widget, hint)
+        self.__size = qApp.font().pointSize()
         self.__initVal()
         self.__initUi()
 
     def __initVal(self):
-        self.__size = 17
         self.__border_width = self.__size // 20
         self.__border_radius = self.__size // 2
         self.__macBtnStyle = ''
@@ -40,4 +41,14 @@ class MacButtonsWidget(TitlebarButtonsWidget):
                              }}
                              '''
 
-        btn.setStyleSheet(self.__macBtnStyle)
\ No newline at end of file
+        btn.setStyleSheet(self.__macBtnStyle)
+
+    def setButtonSize(self, w, h):
+        self.__size = w
+        self.__initVal()
+        btns = [self._closeBtn, self._minimizeBtn, self._maximizeBtn]
+        colors = ['#DD0000', '#AA8800', '#008800']
+        for i in range(len(btns)):
+            btn = btns[i]
+            btn.setFixedSize(self.__size, self.__size)
+            self.__setStyleForEachButton(btn, colors[i])
\ No newline at end of file
